#!/bin/bash
##################################################
## simple job run template for bwUniCluster     ##
## to run chain jobs interactively / with MOAB  ##
##################################################
## ver.  : 2014-09-09, Robert Barthel, KIT, SCC
##
## usage : 
## a) interactively: export myloop_counter=0; ./generalised_chain_job.sh
## b) with MOAB    : msub -v myloop_counter=0 ./generalised_chain_job.sh


#MSUB -l advres=workshop.54,nodes=1:ppn=1
#MSUB -l walltime=00:00:05
#MSUB -l pmem=50mb
#MSUB -N chain

## Defaults
loop_max=10
cmd='sleep 2'

## Check if counter environment variable is set
if [ -z "${myloop_counter}" ] ; then 
   echo "  ERROR: myloop_counter is undefined, stop chain job"
   exit 1
fi

## only continue if below loop_max
if [ ${myloop_counter} -lt ${loop_max} ] ; then

   ## increase counter    
   let myloop_counter+=1
  
   ## print current Job number
   echo "  Chain job iteration = ${myloop_counter}"
   
   ## Execute your command
   echo "  -> executing ${cmd}"
   ${cmd}

   if [ $? -eq 0 ] ; then
      ## continue only if last command was successful
      if [ ! -z ${MOAB_JOBNAME} ] ; then
         ## If MOAB_JOBNAME environment variable is defined 
         ## -> this script is under MOAB "control"
         msub -v myloop_counter=${myloop_counter} ./generalised_chain_job.sh
      else
         export myloop_counter=${myloop_counter}
         ./${0}
      fi
   else
      ## Terminate chain 
      echo "  ERROR: ${cmd} of chain job no. ${myloop_counter} terminated unexpectedly"
      exit 1
   fi
fi
