#!/bin/bash
##################################################
## generalised Job run template for bwUniCluster##
## to run at $TMPDIR                            ##
##################################################
## ver.  : 2015-02-25, Robert Barthel, KIT, SCC
##
## Syntax:
##   ^                         = begin of line
##   <int>                     = integer placeholder
##   ^##                       = comment
##   
##   ^#MSUB -l nodes=<int>:ppn=<int> = defines nodes and cores per node
##   ^#MSUB -l walltime=hh:mm:ss     = defines walltime in hh:mm:ss
##   ^#MSUB -N <jobname>             = defines jobname
##   ^#MSUB -m <email_option>        = defines nofication condition
##
## Note  : 
##   - all '#MSUB -?' are equivalent to 'msub -?'
##   - for more options, see 'man msub'
##   - '# MSUB' is a comment, while '#MSUB' is a msub option statement

##################################################
## HEADER: Define here your Compute resources   ##
##################################################
#MSUB -N test
#MSUB -l advres=workshop.54,nodes=1:ppn=1
#MSUB -l walltime=00:05:00
#MSUB -m n


##################################################
## HEADER: setup environment etc - edit here    ##
##################################################
## a) Load modules if necessary
module load compiler/intel
module load numlib/mkl
 
## b) Define full path of your binary
EXE="gen_files"

## c) Define output file 
output="$(basename ${EXE})_${MOAB_JOBID:-$$}.log"

## d) Define input files 
input="gen_files.inp"

## e) Define your run directory and generate
run_DIR="$TMP/${USER}.${MOAB_JOBID:-$$}"
mkdir -pv "${run_DIR}"

## f) Define input files to be copied
copy_list="${EXE} ${input}"

## g) Define files to be copied back after run, i.e. output file
save_list="${output} files_*.out"


##################################################
## BODY:                                        ##
##################################################
## h) Check existance of run_DIR
if [ ! -d "${run_DIR}" ] ; then
   echo "ERROR: Run DIR = ${run_DIR} does not exist"; exit 1
fi

## i) Copy files from submit_DIR to run_DIR
cd "${MOAB_SUBMITDIR:-${PWD}}"
for X in ${copy_list} ; do
   cp -pv "${X}" "${run_DIR}"
done


## j) cd to runDIR and start binary
cd "${run_DIR}"
./$EXE ${input} > $output 2>&1


##################################################
## FOOTER: check job, cleanup your job etc.     ##
##################################################
## k) Check run status
if [ $? -ne 0 ] ; then
   echo "WARNING: ${EXE} did not run properly!"
fi 

## l) Transfer files to submit directory
cd "${run_DIR}"
for X in ${save_list} ; do
   cp -pv "${X}" "${MOAB_SUBMITDIR:-${PWD}}"
done

## m) Cleanup ${run_DIR}
rm -f ${run_DIR}/*
rmdir ${run_DIR}
exit 0
