#!/bin/bash
##################################################
## simple MOAB submitter script to setup        ## 
## a chain of jobs for bwUniCluster             ##
##################################################
## ver.  : 2015-09-22, Robert Barthel, KIT, SCC

## Define maximum number of jobs to submit (e.g. "5")
max_nojob=5
 
## Define your jobscript (e.g. "~/chain_link_job.sh")
chain_link_job=~/chain_link_job.sh
 
## Define type of dependency
dep_type="afterok"
## -> Possible dependencies are:
##
## afterany       afterany:<job>[:<job>]...  Job may start at any time after all specified jobs have completed regardless of completion status.
## afterok         afterok:<job>[:<job>]...  Job may start at any time after all specified jobs have successfully completed.
##
## -> List of all dependencies:
## http://docs.adaptivecomputing.com/suite/8-0/enterprise/help.htm#topics/moabWorkloadManager/topics/jobAdministration/jobdependencies.html
 
myloop_counter=1
## Submit remaining jobs linking each other
while [ ${myloop_counter} -le ${max_nojob} ]; do
   ##
   ## Differ msub_opt depending on chain link number
   if [ ${myloop_counter} -eq 1 ] ; then
      msub_opt=""
   else
      msub_opt="-W depend=${dep_type}:${jobID}"
   fi
   ##
   ## print current Job number
   echo "Chain job iteration = ${myloop_counter}"
   echo "   msub -v myloop_counter=${counter} ${msub_opt} ${chain_link_job}"
   ## -> by excuting via msub and removing empty lines
   jobID=$(msub -v myloop_counter=${counter} ${msub_opt} ${chain_link_job} 2>&1 | grep -v -e '^$')
   ##   
   ## Check if ERROR occured
   if [[ "${jobID}" =~ "ERROR" ]] ; then
      echo "   -> submission failed!" ; exit 1
   else
      echo "   -> job number = ${jobID}"
   fi   
   ##
   ## Increase counter
   let myloop_counter+=1
done


